==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/EdifactValidationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.TrailingSeparatorPolicy
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Edifact agreement validation settings.
 * @property allowLeadingAndTrailingSpacesAndZeroes The value indicating whether to allow leading and trailing spaces and zeroes.
 * @property checkDuplicateGroupControlNumber The value indicating whether to check for duplicate group control number.
 * @property checkDuplicateInterchangeControlNumber The value indicating whether to check for duplicate interchange control number.
 * @property checkDuplicateTransactionSetControlNumber The value indicating whether to check for duplicate transaction set control number.
 * @property interchangeControlNumberValidityDays The validity period of interchange control number.
 * @property trailingSeparatorPolicy The trailing separator policy.
 * @property trimLeadingAndTrailingSpacesAndZeroes The value indicating whether to trim leading and trailing spaces and zeroes.
 * @property validateCharacterSet The value indicating whether to validate character set in the message.
 * @property validateEDITypes The value indicating whether to Whether to validate EDI types.
 * @property validateXSDTypes The value indicating whether to Whether to validate XSD types.
 */
public data class EdifactValidationSettingsArgs(
    public val allowLeadingAndTrailingSpacesAndZeroes: Output<Boolean>,
    public val checkDuplicateGroupControlNumber: Output<Boolean>,
    public val checkDuplicateInterchangeControlNumber: Output<Boolean>,
    public val checkDuplicateTransactionSetControlNumber: Output<Boolean>,
    public val interchangeControlNumberValidityDays: Output<Int>,
    public val trailingSeparatorPolicy: Output<Either<String, TrailingSeparatorPolicy>>,
    public val trimLeadingAndTrailingSpacesAndZeroes: Output<Boolean>,
    public val validateCharacterSet: Output<Boolean>,
    public val validateEDITypes: Output<Boolean>,
    public val validateXSDTypes: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs =
        com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs.builder()
            .allowLeadingAndTrailingSpacesAndZeroes(
                allowLeadingAndTrailingSpacesAndZeroes.applyValue({ args0 ->
                    args0
                }),
            )
            .checkDuplicateGroupControlNumber(checkDuplicateGroupControlNumber.applyValue({ args0 -> args0 }))
            .checkDuplicateInterchangeControlNumber(
                checkDuplicateInterchangeControlNumber.applyValue({ args0 ->
                    args0
                }),
            )
            .checkDuplicateTransactionSetControlNumber(
                checkDuplicateTransactionSetControlNumber.applyValue({ args0 ->
                    args0
                }),
            )
            .interchangeControlNumberValidityDays(
                interchangeControlNumberValidityDays.applyValue({ args0 ->
                    args0
                }),
            )
            .trailingSeparatorPolicy(
                trailingSeparatorPolicy.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .trimLeadingAndTrailingSpacesAndZeroes(
                trimLeadingAndTrailingSpacesAndZeroes.applyValue({ args0 ->
                    args0
                }),
            )
            .validateCharacterSet(validateCharacterSet.applyValue({ args0 -> args0 }))
            .validateEDITypes(validateEDITypes.applyValue({ args0 -> args0 }))
            .validateXSDTypes(validateXSDTypes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EdifactValidationSettingsArgs].
 */
@PulumiTagMarker
public class EdifactValidationSettingsArgsBuilder internal constructor() {
    private var allowLeadingAndTrailingSpacesAndZeroes: Output<Boolean>? = null

    private var checkDuplicateGroupControlNumber: Output<Boolean>? = null

    private var checkDuplicateInterchangeControlNumber: Output<Boolean>? = null

    private var checkDuplicateTransactionSetControlNumber: Output<Boolean>? = null

    private var interchangeControlNumberValidityDays: Output<Int>? = null

    private var trailingSeparatorPolicy: Output<Either<String, TrailingSeparatorPolicy>>? = null

    private var trimLeadingAndTrailingSpacesAndZeroes: Output<Boolean>? = null

    private var validateCharacterSet: Output<Boolean>? = null

    private var validateEDITypes: Output<Boolean>? = null

    private var validateXSDTypes: Output<Boolean>? = null

    /**
     * @param value The value indicating whether to allow leading and trailing spaces and zeroes.
     */
    @JvmName("qtkqrkqnjhpsvhox")
    public suspend fun allowLeadingAndTrailingSpacesAndZeroes(`value`: Output<Boolean>) {
        this.allowLeadingAndTrailingSpacesAndZeroes = value
    }

    /**
     * @param value The value indicating whether to check for duplicate group control number.
     */
    @JvmName("uwevqpxgkajjvlfq")
    public suspend fun checkDuplicateGroupControlNumber(`value`: Output<Boolean>) {
        this.checkDuplicateGroupControlNumber = value
    }

    /**
     * @param value The value indicating whether to check for duplicate interchange control number.
     */
    @JvmName("bodsadgeesblolrr")
    public suspend fun checkDuplicateInterchangeControlNumber(`value`: Output<Boolean>) {
        this.checkDuplicateInterchangeControlNumber = value
    }

    /**
     * @param value The value indicating whether to check for duplicate transaction set control number.
     */
    @JvmName("ihhrpiurwthdacfg")
    public suspend fun checkDuplicateTransactionSetControlNumber(`value`: Output<Boolean>) {
        this.checkDuplicateTransactionSetControlNumber = value
    }

    /**
     * @param value The validity period of interchange control number.
     */
    @JvmName("slkahvmqxcxpmcpa")
    public suspend fun interchangeControlNumberValidityDays(`value`: Output<Int>) {
        this.interchangeControlNumberValidityDays = value
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("gbkiqgjkxbtjectr")
    public suspend
    fun trailingSeparatorPolicy(`value`: Output<Either<String, TrailingSeparatorPolicy>>) {
        this.trailingSeparatorPolicy = value
    }

    /**
     * @param value The value indicating whether to trim leading and trailing spaces and zeroes.
     */
    @JvmName("uwreffkcuewpgpyg")
    public suspend fun trimLeadingAndTrailingSpacesAndZeroes(`value`: Output<Boolean>) {
        this.trimLeadingAndTrailingSpacesAndZeroes = value
    }

    /**
     * @param value The value indicating whether to validate character set in the message.
     */
    @JvmName("ddbqvacmwdsrdbmn")
    public suspend fun validateCharacterSet(`value`: Output<Boolean>) {
        this.validateCharacterSet = value
    }

    /**
     * @param value The value indicating whether to Whether to validate EDI types.
     */
    @JvmName("hjoujqmmqqjtbubb")
    public suspend fun validateEDITypes(`value`: Output<Boolean>) {
        this.validateEDITypes = value
    }

    /**
     * @param value The value indicating whether to Whether to validate XSD types.
     */
    @JvmName("bpjmchayvowufyiq")
    public suspend fun validateXSDTypes(`value`: Output<Boolean>) {
        this.validateXSDTypes = value
    }

    /**
     * @param value The value indicating whether to allow leading and trailing spaces and zeroes.
     */
    @JvmName("geuvipcxlnckjowe")
    public suspend fun allowLeadingAndTrailingSpacesAndZeroes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowLeadingAndTrailingSpacesAndZeroes = mapped
    }

    /**
     * @param value The value indicating whether to check for duplicate group control number.
     */
    @JvmName("pyayxmeamcfxnuwk")
    public suspend fun checkDuplicateGroupControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.checkDuplicateGroupControlNumber = mapped
    }

    /**
     * @param value The value indicating whether to check for duplicate interchange control number.
     */
    @JvmName("mfccofjwnxxlqnul")
    public suspend fun checkDuplicateInterchangeControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.checkDuplicateInterchangeControlNumber = mapped
    }

    /**
     * @param value The value indicating whether to check for duplicate transaction set control number.
     */
    @JvmName("qqskbcgimlkujicb")
    public suspend fun checkDuplicateTransactionSetControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.checkDuplicateTransactionSetControlNumber = mapped
    }

    /**
     * @param value The validity period of interchange control number.
     */
    @JvmName("lnfqgqgpdestjaos")
    public suspend fun interchangeControlNumberValidityDays(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.interchangeControlNumberValidityDays = mapped
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("eudqtyhwyiexoied")
    public suspend fun trailingSeparatorPolicy(`value`: Either<String, TrailingSeparatorPolicy>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trailingSeparatorPolicy = mapped
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("ubxhqhtetqyfqkjv")
    public fun trailingSeparatorPolicy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TrailingSeparatorPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trailingSeparatorPolicy = mapped
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("txuocjeprratopei")
    public fun trailingSeparatorPolicy(`value`: TrailingSeparatorPolicy) {
        val toBeMapped = Either.ofRight<String, TrailingSeparatorPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trailingSeparatorPolicy = mapped
    }

    /**
     * @param value The value indicating whether to trim leading and trailing spaces and zeroes.
     */
    @JvmName("scualkqdjankyxjh")
    public suspend fun trimLeadingAndTrailingSpacesAndZeroes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trimLeadingAndTrailingSpacesAndZeroes = mapped
    }

    /**
     * @param value The value indicating whether to validate character set in the message.
     */
    @JvmName("lajsruxnilmtwega")
    public suspend fun validateCharacterSet(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validateCharacterSet = mapped
    }

    /**
     * @param value The value indicating whether to Whether to validate EDI types.
     */
    @JvmName("wmgnnhycrmjelwim")
    public suspend fun validateEDITypes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validateEDITypes = mapped
    }

    /**
     * @param value The value indicating whether to Whether to validate XSD types.
     */
    @JvmName("jelfcensgswucswt")
    public suspend fun validateXSDTypes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validateXSDTypes = mapped
    }

    internal fun build(): EdifactValidationSettingsArgs = EdifactValidationSettingsArgs(
        allowLeadingAndTrailingSpacesAndZeroes = allowLeadingAndTrailingSpacesAndZeroes ?: throw
            PulumiNullFieldException("allowLeadingAndTrailingSpacesAndZeroes"),
        checkDuplicateGroupControlNumber = checkDuplicateGroupControlNumber ?: throw
            PulumiNullFieldException("checkDuplicateGroupControlNumber"),
        checkDuplicateInterchangeControlNumber = checkDuplicateInterchangeControlNumber ?: throw
            PulumiNullFieldException("checkDuplicateInterchangeControlNumber"),
        checkDuplicateTransactionSetControlNumber = checkDuplicateTransactionSetControlNumber ?: throw
            PulumiNullFieldException("checkDuplicateTransactionSetControlNumber"),
        interchangeControlNumberValidityDays = interchangeControlNumberValidityDays ?: throw
            PulumiNullFieldException("interchangeControlNumberValidityDays"),
        trailingSeparatorPolicy = trailingSeparatorPolicy ?: throw
            PulumiNullFieldException("trailingSeparatorPolicy"),
        trimLeadingAndTrailingSpacesAndZeroes = trimLeadingAndTrailingSpacesAndZeroes ?: throw
            PulumiNullFieldException("trimLeadingAndTrailingSpacesAndZeroes"),
        validateCharacterSet = validateCharacterSet ?: throw
            PulumiNullFieldException("validateCharacterSet"),
        validateEDITypes = validateEDITypes ?: throw PulumiNullFieldException("validateEDITypes"),
        validateXSDTypes = validateXSDTypes ?: throw PulumiNullFieldException("validateXSDTypes"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/EdifactValidationSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.TrailingSeparatorPolicy
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Edifact agreement validation settings.
 * @property allowLeadingAndTrailingSpacesAndZeroes The value indicating whether to allow leading and trailing spaces and zeroes.
 * @property checkDuplicateGroupControlNumber The value indicating whether to check for duplicate group control number.
 * @property checkDuplicateInterchangeControlNumber The value indicating whether to check for duplicate interchange control number.
 * @property checkDuplicateTransactionSetControlNumber The value indicating whether to check for duplicate transaction set control number.
 * @property interchangeControlNumberValidityDays The validity period of interchange control number.
 * @property trailingSeparatorPolicy The trailing separator policy.
 * @property trimLeadingAndTrailingSpacesAndZeroes The value indicating whether to trim leading and trailing spaces and zeroes.
 * @property validateCharacterSet The value indicating whether to validate character set in the message.
 * @property validateEDITypes The value indicating whether to Whether to validate EDI types.
 * @property validateXSDTypes The value indicating whether to Whether to validate XSD types.
 */
public data class EdifactValidationSettingsArgs(
    public val allowLeadingAndTrailingSpacesAndZeroes: Output<Boolean>,
    public val checkDuplicateGroupControlNumber: Output<Boolean>,
    public val checkDuplicateInterchangeControlNumber: Output<Boolean>,
    public val checkDuplicateTransactionSetControlNumber: Output<Boolean>,
    public val interchangeControlNumberValidityDays: Output<Int>,
    public val trailingSeparatorPolicy: Output<Either<String, TrailingSeparatorPolicy>>,
    public val trimLeadingAndTrailingSpacesAndZeroes: Output<Boolean>,
    public val validateCharacterSet: Output<Boolean>,
    public val validateEDITypes: Output<Boolean>,
    public val validateXSDTypes: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs =
        com.pulumi.azurenative.logic.inputs.EdifactValidationSettingsArgs.builder()
            .allowLeadingAndTrailingSpacesAndZeroes(
                allowLeadingAndTrailingSpacesAndZeroes.applyValue({ args0 ->
                    args0
                }),
            )
            .checkDuplicateGroupControlNumber(checkDuplicateGroupControlNumber.applyValue({ args0 -> args0 }))
            .checkDuplicateInterchangeControlNumber(
                checkDuplicateInterchangeControlNumber.applyValue({ args0 ->
                    args0
                }),
            )
            .checkDuplicateTransactionSetControlNumber(
                checkDuplicateTransactionSetControlNumber.applyValue({ args0 ->
                    args0
                }),
            )
            .interchangeControlNumberValidityDays(
                interchangeControlNumberValidityDays.applyValue({ args0 ->
                    args0
                }),
            )
            .trailingSeparatorPolicy(
                trailingSeparatorPolicy.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .trimLeadingAndTrailingSpacesAndZeroes(
                trimLeadingAndTrailingSpacesAndZeroes.applyValue({ args0 ->
                    args0
                }),
            )
            .validateCharacterSet(validateCharacterSet.applyValue({ args0 -> args0 }))
            .validateEDITypes(validateEDITypes.applyValue({ args0 -> args0 }))
            .validateXSDTypes(validateXSDTypes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EdifactValidationSettingsArgs].
 */
@PulumiTagMarker
public class EdifactValidationSettingsArgsBuilder internal constructor() {
    private var allowLeadingAndTrailingSpacesAndZeroes: Output<Boolean>? = null

    private var checkDuplicateGroupControlNumber: Output<Boolean>? = null

    private var checkDuplicateInterchangeControlNumber: Output<Boolean>? = null

    private var checkDuplicateTransactionSetControlNumber: Output<Boolean>? = null

    private var interchangeControlNumberValidityDays: Output<Int>? = null

    private var trailingSeparatorPolicy: Output<Either<String, TrailingSeparatorPolicy>>? = null

    private var trimLeadingAndTrailingSpacesAndZeroes: Output<Boolean>? = null

    private var validateCharacterSet: Output<Boolean>? = null

    private var validateEDITypes: Output<Boolean>? = null

    private var validateXSDTypes: Output<Boolean>? = null

    /**
     * @param value The value indicating whether to allow leading and trailing spaces and zeroes.
     */
    @JvmName("nbncqfgjvnebvnky")
    public suspend fun allowLeadingAndTrailingSpacesAndZeroes(`value`: Output<Boolean>) {
        this.allowLeadingAndTrailingSpacesAndZeroes = value
    }

    /**
     * @param value The value indicating whether to check for duplicate group control number.
     */
    @JvmName("ppavdrkpludumarq")
    public suspend fun checkDuplicateGroupControlNumber(`value`: Output<Boolean>) {
        this.checkDuplicateGroupControlNumber = value
    }

    /**
     * @param value The value indicating whether to check for duplicate interchange control number.
     */
    @JvmName("explqkdoentlhtlp")
    public suspend fun checkDuplicateInterchangeControlNumber(`value`: Output<Boolean>) {
        this.checkDuplicateInterchangeControlNumber = value
    }

    /**
     * @param value The value indicating whether to check for duplicate transaction set control number.
     */
    @JvmName("ghxyggkjmkjvdiar")
    public suspend fun checkDuplicateTransactionSetControlNumber(`value`: Output<Boolean>) {
        this.checkDuplicateTransactionSetControlNumber = value
    }

    /**
     * @param value The validity period of interchange control number.
     */
    @JvmName("gbyounthxqchyhhn")
    public suspend fun interchangeControlNumberValidityDays(`value`: Output<Int>) {
        this.interchangeControlNumberValidityDays = value
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("hefdermontokryyp")
    public suspend
    fun trailingSeparatorPolicy(`value`: Output<Either<String, TrailingSeparatorPolicy>>) {
        this.trailingSeparatorPolicy = value
    }

    /**
     * @param value The value indicating whether to trim leading and trailing spaces and zeroes.
     */
    @JvmName("vmtvdwyyswclkiot")
    public suspend fun trimLeadingAndTrailingSpacesAndZeroes(`value`: Output<Boolean>) {
        this.trimLeadingAndTrailingSpacesAndZeroes = value
    }

    /**
     * @param value The value indicating whether to validate character set in the message.
     */
    @JvmName("ailyggqvsgceorbi")
    public suspend fun validateCharacterSet(`value`: Output<Boolean>) {
        this.validateCharacterSet = value
    }

    /**
     * @param value The value indicating whether to Whether to validate EDI types.
     */
    @JvmName("wqakehmsppxsvquh")
    public suspend fun validateEDITypes(`value`: Output<Boolean>) {
        this.validateEDITypes = value
    }

    /**
     * @param value The value indicating whether to Whether to validate XSD types.
     */
    @JvmName("odjfywttofbbrohf")
    public suspend fun validateXSDTypes(`value`: Output<Boolean>) {
        this.validateXSDTypes = value
    }

    /**
     * @param value The value indicating whether to allow leading and trailing spaces and zeroes.
     */
    @JvmName("lwydektreqesthxe")
    public suspend fun allowLeadingAndTrailingSpacesAndZeroes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowLeadingAndTrailingSpacesAndZeroes = mapped
    }

    /**
     * @param value The value indicating whether to check for duplicate group control number.
     */
    @JvmName("bcjqltggqyksdwuq")
    public suspend fun checkDuplicateGroupControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.checkDuplicateGroupControlNumber = mapped
    }

    /**
     * @param value The value indicating whether to check for duplicate interchange control number.
     */
    @JvmName("cosacdphgiuiguti")
    public suspend fun checkDuplicateInterchangeControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.checkDuplicateInterchangeControlNumber = mapped
    }

    /**
     * @param value The value indicating whether to check for duplicate transaction set control number.
     */
    @JvmName("sshbqytvdmtnkqpq")
    public suspend fun checkDuplicateTransactionSetControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.checkDuplicateTransactionSetControlNumber = mapped
    }

    /**
     * @param value The validity period of interchange control number.
     */
    @JvmName("pdprssffvjquyfgv")
    public suspend fun interchangeControlNumberValidityDays(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.interchangeControlNumberValidityDays = mapped
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("ljjiarpxslecnbng")
    public suspend fun trailingSeparatorPolicy(`value`: Either<String, TrailingSeparatorPolicy>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trailingSeparatorPolicy = mapped
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("dssjtlggojrfwhmi")
    public fun trailingSeparatorPolicy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TrailingSeparatorPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trailingSeparatorPolicy = mapped
    }

    /**
     * @param value The trailing separator policy.
     */
    @JvmName("afcebdkjcoolptdo")
    public fun trailingSeparatorPolicy(`value`: TrailingSeparatorPolicy) {
        val toBeMapped = Either.ofRight<String, TrailingSeparatorPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trailingSeparatorPolicy = mapped
    }

    /**
     * @param value The value indicating whether to trim leading and trailing spaces and zeroes.
     */
    @JvmName("ntcnhgaeggdjwivd")
    public suspend fun trimLeadingAndTrailingSpacesAndZeroes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.trimLeadingAndTrailingSpacesAndZeroes = mapped
    }

    /**
     * @param value The value indicating whether to validate character set in the message.
     */
    @JvmName("jbumsqnkkgyctoqi")
    public suspend fun validateCharacterSet(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validateCharacterSet = mapped
    }

    /**
     * @param value The value indicating whether to Whether to validate EDI types.
     */
    @JvmName("ydttglossljuersv")
    public suspend fun validateEDITypes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validateEDITypes = mapped
    }

    /**
     * @param value The value indicating whether to Whether to validate XSD types.
     */
    @JvmName("tvdengpfitdgindi")
    public suspend fun validateXSDTypes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.validateXSDTypes = mapped
    }

    internal fun build(): EdifactValidationSettingsArgs = EdifactValidationSettingsArgs(
        allowLeadingAndTrailingSpacesAndZeroes = allowLeadingAndTrailingSpacesAndZeroes ?: throw
            PulumiNullFieldException("allowLeadingAndTrailingSpacesAndZeroes"),
        checkDuplicateGroupControlNumber = checkDuplicateGroupControlNumber ?: throw
            PulumiNullFieldException("checkDuplicateGroupControlNumber"),
        checkDuplicateInterchangeControlNumber = checkDuplicateInterchangeControlNumber ?: throw
            PulumiNullFieldException("checkDuplicateInterchangeControlNumber"),
        checkDuplicateTransactionSetControlNumber = checkDuplicateTransactionSetControlNumber ?: throw
            PulumiNullFieldException("checkDuplicateTransactionSetControlNumber"),
        interchangeControlNumberValidityDays = interchangeControlNumberValidityDays ?: throw
            PulumiNullFieldException("interchangeControlNumberValidityDays"),
        trailingSeparatorPolicy = trailingSeparatorPolicy ?: throw
            PulumiNullFieldException("trailingSeparatorPolicy"),
        trimLeadingAndTrailingSpacesAndZeroes = trimLeadingAndTrailingSpacesAndZeroes ?: throw
            PulumiNullFieldException("trimLeadingAndTrailingSpacesAndZeroes"),
        validateCharacterSet = validateCharacterSet ?: throw
            PulumiNullFieldException("validateCharacterSet"),
        validateEDITypes = validateEDITypes ?: throw PulumiNullFieldException("validateEDITypes"),
        validateXSDTypes = validateXSDTypes ?: throw PulumiNullFieldException("validateXSDTypes"),
    )
}
